@@ -99,6 +99,13 @@ def _positive_float(arg) -> float:
     raise argparse.ArgumentTypeError("Not a positive float")
 
 
+def _nonnegative_float(arg) -> float:
+    if (n := float(arg)) >= 0:
+        return n
+
+    raise argparse.ArgumentTypeError("Not a nonnegative float")
+
+
 def _positive_int(arg) -> int:
     if (n := int(arg)) > 0:
         return n
@@ -226,7 +233,8 @@ def _make_stripepy_call_subcommand(main_parser) -> argparse.ArgumentParser:
         "--constrain-heights",
         action="store_true",
         default=False,
-        help="Use peaks in signal to constrain the stripe height (default: %(default)s).",
+        help=argparse.SUPPRESS,
+        # help="Use peaks in signal to constrain the stripe height (default: %(default)s).",
     )
 
     sc.add_argument(
@@ -243,7 +251,7 @@ def _make_stripepy_call_subcommand(main_parser) -> argparse.ArgumentParser:
         type=_probability,
         default=0.33,
         help="Threshold value between 0 and 1 to find peaks in signal in a horizontal domain while estimating the "
-        "height of a stripe; when --constrain-heights is set to 'False', it is not used (default: %(default)s).",
+        "height of a stripe (default: %(default)s).",
     )
 
     sc.add_argument(
@@ -251,9 +259,8 @@ def _make_stripepy_call_subcommand(main_parser) -> argparse.ArgumentParser:
         type=_probability,
         default=0.25,
         help="Threshold value between 0 and 1 to estimate the height of a stripe (default: %(default)s); "
-        "the higher this value, the shorter the stripe; it is always used when --constrain-heights is set to "
-        "'False', but could be necessary also when --constrain-heights is 'True' and no persistent maximum other "
-        "than the global maximum is found.",
+        "the higher this value, the shorter the stripe; it is used to avoid overly long stripes when no persistent "
+        "maximum besides the global one is found.",
     )
 
     sc.add_argument(
@@ -299,14 +306,18 @@ def _make_stripepy_download_subcommand(main_parser) -> argparse.ArgumentParser:
         allow_abbrev=False,
     )
 
-    def get_avail_ref_genomes():
+    def get_avail_ref_genomes() -> List[str]:
         from stripepy.cli.download import _get_datasets  # noqa
 
-        return {
-            record["assembly"]
-            for record in _get_datasets(math.inf, include_private=False).values()
-            if "assembly" in record
-        }
+        return list(
+            sorted(
+                {
+                    record["assembly"]
+                    for record in _get_datasets(math.inf, include_private=False).values()
+                    if "assembly" in record
+                }
+            )
+        )
 
     grp = sc.add_mutually_exclusive_group(required=False)
     grp.add_argument(
@@ -491,6 +502,15 @@ def _make_stripepy_plot_subcommand(main_parser) -> argparse.ArgumentParser:
         "found inside a stripe and the number of interactions in a neighborhood outside of the stripe.",
     )
 
+    sc.add_argument(
+        "--coefficient-of-variation-threshold",
+        type=_nonnegative_float,
+        help="Cutoff for the coefficient of variation (default: %(default)s).\n"
+        "Only used when highlighting architectural stripes.\n"
+        "The coefficient of variation is computed as the ratio between the standard deviation and the mean \n"
+        "of the values inside a stripe. In our case, it is always nonnegative because of the preprocessing step.",
+    )
+
     grp = sc.add_mutually_exclusive_group()
     grp.add_argument(
         "--highlight-seeds",
@@ -587,6 +607,15 @@ def _make_stripepy_view_subcommand(main_parser) -> argparse.ArgumentParser:
         "found inside a stripe and the number of interactions in a neighborhood outside of the stripe.",
     )
 
+    sc.add_argument(
+        "--coefficient-of-variation-threshold",
+        type=_nonnegative_float,
+        default=None,
+        help="Cutoff for the coefficient of variation (default: %(default)s).\n"
+        "The coefficient of variation is computed as the ratio between the standard deviation and the mean \n"
+        "of the values inside a stripe. In our case, it is always nonnegative because of the preprocessing step.",
+    )
+
     sc.add_argument(
         "--with-biodescriptors",
         action="store_true",
@@ -604,7 +633,7 @@ def _make_stripepy_view_subcommand(main_parser) -> argparse.ArgumentParser:
     sc.add_argument(
         "--transform",
         type=str,
-        choices={"transpose_to_ut", "transpose_to_lt", None},
+        choices=(None, "transpose_to_lt", "transpose_to_ut"),
         default=None,
         help="Control if and how stripe coordinates should be transformed (default: %(default)s).",
     )
