@@ -2,6 +2,7 @@
 #
 # SPDX-License-Identifier: MIT
 
+import math
 import pathlib
 import sys
 from typing import Optional
@@ -17,12 +18,17 @@ def run(
     relative_change_threshold: float,
     with_biodescriptors: bool,
     with_header: bool,
+    coefficient_of_variation_threshold: Optional[float] = None,
     transform: Optional[str] = None,
     main_logger=None,
     telem_span=None,
 ) -> int:
     try:
-        _configure_telemetry(telem_span, relative_change_threshold=relative_change_threshold)
+        _configure_telemetry(
+            telem_span,
+            relative_change_threshold=relative_change_threshold,
+            coefficient_of_variation_threshold=coefficient_of_variation_threshold,
+        )
         skip_telemetry = telem_span is None
         with ResultFile(h5_file) as f:
             for chrom, size in f.chromosomes.items():
@@ -32,6 +38,7 @@ def run(
                     size,
                     f.resolution,
                     relative_change_threshold,
+                    coefficient_of_variation_threshold,
                     transform,
                     with_biodescriptors,
                     with_header,
@@ -39,22 +46,48 @@ def run(
                 )
                 with_header = False
                 skip_telemetry = True
-    except BrokenPipeError:
-        if sys.stdout.isatty():
-            raise
+    except BrokenPipeError as e:
+        _handle_broken_pipe_error(e)
 
     return 0
 
 
+def _handle_broken_pipe_error(e: BrokenPipeError):
+    """
+    Handle BrokenPipeError exceptions due to e.g. piping stripepy view into a command like head.
+    This needs to deal with the following cases:
+    - stdout is a tty: report the exception to the user
+    - stdout is not a tty: forcefully close stdout and ignore BrokenPipeErrors.
+      This is required to avoid errors like the following on macOS:
+        Exception ignored on flushing sys.stdout:
+        BrokenPipeError: [Errno 32] Broken pipe
+        Command exited with non-zero status 120
+    """
+
+    if sys.stdout.isatty():
+        raise e
+
+    try:
+        sys.stdout.close()
+    except BrokenPipeError:
+        # Make sure we exit with a clean code no matter what
+        sys.exit(0)
+
+
 def _configure_telemetry(
     span,
     relative_change_threshold: float,
+    coefficient_of_variation_threshold: Optional[float],
 ):
     try:
         if not span.is_recording():
             return
 
+        if coefficient_of_variation_threshold is None:
+            coefficient_of_variation_threshold = math.nextafter(math.inf, 0)
+
         span.set_attribute("params.relative_change_threshold", relative_change_threshold)
+        span.set_attribute("params.coefficient_of_variation_threshold", coefficient_of_variation_threshold)
     except:  # noqa
         pass
 
@@ -147,7 +180,8 @@ def _dump_stripes(
     chrom: str,
     size: int,
     resolution: int,
-    cutoff: float,
+    relative_change_threshold: float,
+    coefficient_of_variation_threshold: Optional[float],
     transpose_policy: str,
     with_biodescriptors: bool,
     with_header: bool,
@@ -157,7 +191,10 @@ def _dump_stripes(
     if df is None:
         return
 
-    df = df[df["rel_change"] >= cutoff]
+    df = df[df["rel_change"] >= relative_change_threshold]
+    if coefficient_of_variation_threshold is not None:
+        df = df[df["cfx_of_variation"] < coefficient_of_variation_threshold]
+
     df = _stripes_to_bedpe(
         df,
         chrom,
@@ -173,4 +210,10 @@ def _dump_stripes(
         columns=df.columns,
     )
 
-    df.to_csv(sys.stdout, sep="\t", index=False, header=with_header)
+    df.to_csv(
+        sys.stdout,
+        sep="\t",
+        index=False,
+        header=with_header,
+        na_rep="nan",
+    )
